module Config.Pages.Debate.Arguments.Inferences.PlantBasedCVDReversal exposing (..)

import Config.Pages.Debate.Arguments.Types exposing (..)


argumentPlantBasedCVDReversal : Argument
argumentPlantBasedCVDReversal =
    { argumentTitle = "Argument Against Plant-Based CVD Reversal"
    , propositionTitle = "Plant-based diets do not appear to clinically reverse atherosclerosis."
    , propositionReductio = ""
    , propositionSummary = "To date, there is not a single case of supposed heart disease reversal from a plant-based diet that is actually compatible with  established definitions of heart disease reversal in the literature."
    , proofLink  = "https://www.umsu.de/trees/#(P~1~3Q~5~3R),(P),(~3Q)|=(~3R)"
    
    , argumentCertainty = 8
    , argumentImage = "plantbasedcvd"
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "there are established definitions for atherosclerosis reversal in the domain of cardiology"
          }
        , { definiendum = "Q"
          , definiens = "current research on plant-based diets and atherosclerosis reversal satisfy the definitions for atherosclerosis reversal in the domain of cardiology"
          }
        , { definiendum = "R"
          , definiens = "plant-based diets do not appear to clinically reverse atherosclerosis"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If there are established definitions for atherosclerosis reversal in the domain of cardiology and current research on plant-based diets and atherosclerosis reversal do not satisfy the definitions for atherosclerosis reversal in the domain of cardiology, then plant-based diets do not appear to clinically reverse atherosclerosis."
                  , notation = "P∧¬Q→¬R"
                  }
                , { premise = "There are established definitions for atherosclerosis reversal in the domain of cardiology."
                  , notation = "P"
                  }
                , { premise = "Current research on plant-based diets and atherosclerosis reversal do not satisfy the definitions for atherosclerosis reversal in the domain of cardiology."
                  , notation = "¬Q"
                  }
                ]
          , conclusion = "Therefore, plant-based diets do not appear to clinically reverse atherosclerosis."
          , conclusionNotation = "¬R"
          }
        ]
    }