module Config.Pages.Debate.Arguments.Inferences.TMAOCausality exposing (..)

import Config.Pages.Debate.Arguments.Types exposing (..)


argumentTMAOCausality : Argument
argumentTMAOCausality =
    { argumentTitle = "Argument Against TMAO Being Causal in CVD"
    , propositionReductio = ""
    , propositionTitle = "TMAO is not likely to be causative of heart disease."
    , propositionSummary = "In the strongest research we have on the relationship between TMAO and heart disease risk, such as with Mendelian randomization and genome-wide associational studies, there is no persuasive causal link between TMAO in the blood and heart disease risk."
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(~3Qt)|=(~3Pt)"
    
    , argumentCertainty = 9
    , argumentImage = "tmaocausality"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is likely to be causative of heart diseas"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently associates with an increased risk of heart disease after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a substance"
          }
        , { definiendum = "t"
          , definiens = "TMAO"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a substance is likely to be causative of heart disease if, then the substance consistently associates with an increased risk of heart disease after adjustment or control over relevant confounders and covariates."
                  , notation = "∀x(Px↔Qx)"
                  }
                , { premise = "TMAO consistently associates with an increased risk of heart disease after adjustment or control over relevant confounders and covariates."
                  , notation = "¬Qt"
                  }
                ]
          , conclusion = "Therefore, TMAO is not likely to be causative of heart disease."
          , conclusionNotation = "¬Pt"
          }
        ]
    }