module Pages.Gibberish exposing (Model, Msg, page)

import Config.Data.Identity exposing (pageNames)
import Config.Format.Response
    exposing
        ( pageList
        , topLevelContainer
        )
import Config.Helpers.Viewport exposing (resetViewport)
import Config.Pages.Debate.Arguments.Helpers exposing (..)
import Config.Pages.Debate.Arguments.Types exposing (..)
import Config.Pages.Debate.Gibberish.Domains.Epistemology exposing (epistemologyGibberish)
import Config.Pages.Debate.Gibberish.Domains.Metaphysics exposing (metaphysicsGibberish)
import Config.Pages.Debate.Gibberish.Domains.Normativity exposing (normativityGibberish)
import Config.Pages.Debate.Gibberish.Domains.Ontology exposing (ontologyGibberish)
import Config.Pages.Debate.Gibberish.Domains.PhilOfLanguage exposing (philOfLanguageGibberish)
import Config.Pages.Debate.Gibberish.Domains.PhilOfMind exposing (philOfMindGibberish)
import Config.Pages.Debate.Gibberish.Domains.Theology exposing (theologyGibberish)
import Config.Pages.Debate.Gibberish.Helpers exposing (..)
import Config.Pages.Headers.Helpers exposing (headerMaker)
import Config.Pages.Headers.Pages.Gibberish exposing (gibberishHeader)
import Effect exposing (Effect)
import Element as E exposing (..)
import Layouts
import List.Extra as L exposing (..)
import Page exposing (Page)
import Route exposing (Route)
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.batch
        [ Effect.map
            (\_ -> NoOp)
            (Effect.sendCmd resetViewport)
        , Effect.none
        ]
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = "debate (" ++ pageNames.pageGibberish ++ ")"
    , attributes = []
    , element = gibberishContainer shared.device
    }


gibberishContainer : Device -> Element msg
gibberishContainer device =
    topLevelContainer (gibberishList device)


gibberishList : Device -> Element msg
gibberishList device =
    column
        (case ( device.class, device.orientation ) of
            _ ->
                pageList
        )
    <|
        List.concat
            [ List.map headerMaker
                [ gibberishHeader ]
            , (case ( device.class, device.orientation ) of
                ( Phone, Portrait ) ->
                    List.map mobileGibberishMaker

                ( Tablet, Portrait ) ->
                    List.map mobileGibberishMaker

                _ ->
                    List.map desktopGibberishMaker
              )
                [ epistemologyGibberish
                , theologyGibberish
                , metaphysicsGibberish
                , normativityGibberish
                , ontologyGibberish
                , philOfMindGibberish
                , philOfLanguageGibberish
                ]
            ]
